/*************

The contents of this file are subject to the Mozilla Public
License Version 1.1 (the "License"); you may not use this file
except in compliance with the License. You may obtain a copy of
the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS
IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
implied. See the License for the specific language governing
rights and limitations under the License.

The Original Code is Alphanumerica code.
The Initial Developer of the Original Code is Alphanumerica.

Portions created by Alphanumerica are
Copyright (C) 2000 Alphanumerica.  All
Rights Reserved.

Contributor(s): Josh Lerner, Dave Boswell, Pete Collins 

************/

const CRASH_OK            = true;
const DEBUG               = true;

const JS_FILE             = "crash.js";
const G_CRASH_FILE        = "crash.rdf";

const PREF_DIR            = "PrefD";

const WIN_CID             = "@mozilla.org/rdf/datasource;1?name=window-mediator";
const DIR_CID             = "@mozilla.org/file/directory_service;1";
const RDF_CID             = "@mozilla.org/rdf/rdf-service;1";

const I_PROP              = "nsIProperties";
const I_RDF               = "nsIRDFService";

const G_REC_TOGGLE_ID     = "recovery-toggle";
const G_CRASH_REC_ID      = "crash-recovery";

const G_CHECKED           = "checked";
const G_DEFAULT_PERM      = 0644;
const CRASH_WRITE         = "w";

const G_CHROME_URL        = "chrome://aphrodite/content/";
const G_BLANK             = "_blank";

/************* DEBUG *****************/
function debugCrash(aString){

  if(DEBUG)
    dump(aString);  

  return CRASH_OK;

}
/************* DEBUG *****************/

function generateWindowInfo(){

try
{

var windowManager = Components.classes[WIN_CID].getService();
var win = windowManager.QueryInterface(Components.interfaces.nsIWindowMediator);

var enumerator = win.getEnumerator( null );

var winContent="";
var i=1;

var pat = new RegExp("&", "g");

	while ( enumerator.hasMoreElements()  )
	{
        var  windowInfo = enumerator.getNext();
        var domWindow = win.convertISupportsToDOMWindow( windowInfo );

				try { var url         = domWindow._content.location.toString(); }

				catch(e){ dump("crash.js:ERROR:"+e.name+" "+e.message+"\n\n"); }

				if(!url)
					break;

        	var name        = domWindow.name;
        	var width       = domWindow._content.outerWidth;
        	var height      = domWindow._content.outerHeight;
        	var x           = domWindow._content.screenX;
        	var y           = domWindow._content.screenY;
        	var title       = domWindow._content.window.document.title.toString();

        	if(title == "")
        		title = url;

        	winContent      += 
        	'\t  <rdf:li>\n'                                        +
        	'\t   <rdf:Description id="win'+i+'">\n'                +
        	'\t    <nc:name><![CDATA['+title+']]></nc:name>\n'      +
        	'\t     <nc:url><![CDATA['+url+']]></nc:url>\n'         +
        	'\t      <nc:objname>win'+i+'</nc:objname>\n'           +
        	'\t       <nc:width>'+width+'</nc:width>\n'             +
        	'\t      <nc:height>'+height+'</nc:height>\n'           +
        	'\t     <nc:x>'+x+'</nc:x>\n'                           +
        	'\t    <nc:y>'+y+'</nc:y>\n'                            +
        	'\t   </rdf:Description>\n'                             +
        	'\t  </rdf:li>\n';

        	i++;

	}
}

catch(e){}

  return winContent;

}



function writeCrashFile(){


        //Make sure Recall is enabled before we write
        var menu        = document.getElementById(G_REC_TOGGLE_ID);
        var check       = eval(menu.getAttribute(G_CHECKED));

        if(!check)
          return null;

        var template =          

        '<?xml version="1.0"?>\n'                                               +
        '<rdf:RDF\n'                                                            +
        '\txmlns:rdf       = "http://www.w3.org/1999/02/22-rdf-syntax-ns#"\n'   +
        '\txmlns:nc        = "http://home.netscape.com/NC-rdf#">\n'             +
        '\t <rdf:Description about="urn:root">\n'                               +
        '\t  <nc:window>\n'                                                     +
        '\t    <rdf:Seq ID="root">\n'                                           +
        generateWindowInfo()                                                    +
        '\t    </rdf:Seq>\n'                                                    +
        '\t  </nc:window>\n'                                                    +
        '\t </rdf:Description>\n'                                               +
        '</rdf:RDF>\n';         

        var cd          = getCrashDir();

        var fileName    = G_CRASH_FILE;
        var f           = new File();
        var fullName    = f.append(cd,fileName);

        var file        = new File(fullName, CRASH_WRITE);

        file.write(template, G_DEFAULT_PERM);
        file.close();

        return CRASH_OK;
}



function getCrashDir(){

    var CR_FILE = new Components.Constructor(DIR_CID, I_PROP);
    var cf      = new CR_FILE();


    var retval;
    try{

        var prop = PREF_DIR;
        var file = cf.get(prop, Components.interfaces.nsIFile);
        retval=file.path;

    }

    catch (e) 
    { 
      dump(JS_FILE+":getCrashDir:ERROR: "+e.name+e.message+"\n");
      retval=null;
    }

  return retval;
}

function crashRecovery(){

    var RDF = new Components.Constructor(RDF_CID, I_RDF);
    var rdf = new RDF();

    var f             = new File();
    var crash_file    = f.append(getCrashDir(),  G_CRASH_FILE);


    if(navigator.platform.match("Mac"))
      crash_file      = "file:///"+crash_file.replace(/:/g,"/");

    else
      crash_file      = "file:///"+crash_file.replace(/\\/g,"/");


    var ds = rdf.GetDataSource(crash_file);

    var menu = document.getElementById(G_CRASH_REC_ID);

    menu.database.AddDataSource(ds);

    menu.builder.rebuild();

}



function launchWindow(node){

var pat = new RegExp("&amp;", "g");

var datasource = document.getElementById(G_CRASH_REC_ID).database;

var RDF = new Components.Constructor(RDF_CID, I_RDF);

var rdf = new RDF();

var value               = node.getAttribute('value');
var url                 = node.getAttribute('win_url').toString();
var name                = node.getAttribute('win_name');
var width               = node.getAttribute('win_width');
var height              = node.getAttribute('win_height');
var x                   = node.getAttribute('win_x');
var y                   = node.getAttribute('win_y');

if(pat.test(url) )
url                     = url.replace(pat, "&");

var args                = "width="+width+",height="+height+",screenX="+x+",screenY="+y;

openLink                = url;

window.openDialog(G_CHROME_URL, G_BLANK, "chrome,all,dialog=no"+args, url );

}

/************* no longer needed *********************
function toggleRecovery(ID){

    var menu            = document.getElementById(ID);
    var checked         = eval(menu.getAttribute(G_CHECKED));

    if(checked)
    menu.setAttribute(G_CHECKED, false);

    else
    menu.setAttribute(G_CHECKED, true);
    

}

************* no longer needed *********************/

